import { login, logout, getInfo, refreshToken } from '@/api/login'
import { getToken, setToken, removeToken, setExpiresIn, getClientToken, setClientToken, removeClientToken, getUSerToken, setUserToken, removeUSerToken } from '@/utils/auth'
import { singleSigngetInfo, enterpriseLogout, governmentGetInfo } from "@/api/jin_ji_hu/login"

const user = {
  state: {
    token: getToken(),
    clientToken: getClientToken(),
    userToken: getUSerToken(),
    id: '',
    name: '',
    avatar: '',
    roles: [],
    permissions: [],
    expires_in: '',
    enterpriseId: '',
    nickName: '',
    userType: '',
    deptId: '',
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_CLIENTTOKEN: (state, token) => {
      state.clientToken = token
    },
    SET_USERTOKEN: (state, token) =>{
      state.userToken = token
    },
    SET_EXPIRES_IN: (state, time) => {
      state.expires_in = time
    },
    SET_ID: (state, id) => {
      state.id = id
    },
    SET_NAME: (state, name) => {
      state.name = name
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
    },
    SET_PERMISSIONS: (state, permissions) => {
      state.permissions = permissions
    },
    SET_ENTERPRISEID: (state, enterpriseId) => {
      state.enterpriseId = enterpriseId
    },
    SET_NICKNAME: (state, nickName) => {
      state.nickName = nickName
    },
    SET_USERTYPE: (state, userType) => {
      state.userType = userType
    },
    SET_DEPTID: (state, deptId) => {
      state.deptId = deptId
    }
  },

  actions: {
    // 登录
    Login({ commit }, userInfo) {
      const username = userInfo.username.trim()
      const password = userInfo.password
      const userType = userInfo.userType
      const code = userInfo.code
      const uuid = userInfo.uuid
      return new Promise((resolve, reject) => {
        login(username, password, code, uuid, userType).then(res => {
          // setToken(res.token)
          // commit('SET_TOKEN', res.token)
          // resolve()
          let data = res.data
          setToken(data.access_token)
          commit('SET_TOKEN', data.access_token)
          setExpiresIn(data.expires_in)
          commit('SET_EXPIRES_IN', data.expires_in)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 企业端登录
    SingleSignOnGetInfo({ commit, state },info) {
      return new Promise((resolve, reject) => {
        singleSigngetInfo({clientToken: info.clientToken}).then(res => {
          // if (res.data.usertype && res.data.usertype.length > 0) { // 验证返回的roles是否是一个非空数组
          //   let roles = [];
          //   roles.push(res.data.usertype)
          //   commit('SET_ROLES', roles)
          // } else {
          //   commit('SET_ROLES', ['ROLE_DEFAULT'])
          // }
          setClientToken(info.clientToken)
          commit('SET_CLIENTTOKEN', res.data.token)
          setToken(res.data.token)
          commit('SET_TOKEN', res.data.token)
          // commit('SET_USERTYPE', res.data.usertype)
          // console.log(res.data.usertype,"res.data.usertype");
          // console.log(state.roles,"state.roles");
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 政务端登录
    governmentLogin({ commit, state },info) {
      return new Promise((resolve, reject) => {
        governmentGetInfo(info).then(res => {
          // console.log(res);
          setUserToken(info.userToken)
          commit('SET_USERTOKEN', res.data.token)
          setToken(res.data.token)
          commit('SET_TOKEN', res.data.token)
          resolve()
        }).catch(error => {
          console.log(error);
          // reject(error)
        })
      })
    },

    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo().then(res => {
          // console.log(res);
          const user = res.user
          const avatar = (user.avatar == "" || user.avatar == null) ? require("@/assets/images/profile.jpg") : process.env.VUE_APP_BASE_API + user.avatar;
          if (res.roles && res.roles.length > 0) { // 验证返回的roles是否是一个非空数组
            commit('SET_ROLES', res.roles)
            commit('SET_PERMISSIONS', res.permissions)
          } else {
            commit('SET_ROLES', ['ROLE_DEFAULT'])
          }
          commit('SET_ID', user.userId)
          commit('SET_NAME', user.userName)
          commit('SET_ENTERPRISEID', user.enterpriseId)
          commit('SET_NICKNAME', user.nickName)
          commit('SET_USERTYPE', user.userType)
          commit('SET_DEPTID', user.deptId)
          commit('SET_AVATAR', avatar)
          resolve(res)
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 刷新token
    RefreshToken({commit, state}) {
      return new Promise((resolve, reject) => {
        refreshToken(state.token).then(res => {
          setExpiresIn(res.data)
          commit('SET_EXPIRES_IN', res.data)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 退出系统
    LogOut({ commit, state }) {
      if(state.userType == "01") {
        return new Promise((resolve, reject) => {
          enterpriseLogout({clienttoken: state.clientToken}).then(()=>{
            commit('SET_CLIENTTOKEN', '')
            removeClientToken()
            logout(state.token).then(() => {
              commit('SET_TOKEN', '')
              commit('SET_ROLES', [])
              commit('SET_PERMISSIONS', [])
              removeToken()
              resolve({userType:state.userType})
            })
          }).catch(error => {
            reject(error)
          })
        })
      } else {
        return new Promise((resolve, reject) => {
          logout(state.token).then(() => {
            commit('SET_TOKEN', '')
            commit('SET_ROLES', [])
            commit('SET_PERMISSIONS', [])
            removeToken()
            resolve({userType:state.userType})
          }).catch(error => {
            reject(error)
          })
        })
      }
    },

    // 前端 登出
    FedLogOut({ commit }) {
      return new Promise(resolve => {
        commit('SET_TOKEN', '')
        removeToken()
        resolve()
      })
    }
  }
}

export default user
